@@ -2,8 +2,9 @@ import socket
 import serial
 class Server:
     """This class create a server"""
-    def __init__(self, port,usbport):
+    def __init__(self, port,usbport,ip):
         """This function called when an object is created"""
+        self.ip = ip
         self.s = None
         self.host = ""
         self.port = port
@@ -44,8 +45,11 @@ class Server:
         """This function accepts the connection requested from client """
         self.s.listen(5)
         self.conn,self.addr = self.s.accept()
-        self.getdata()
-        self.conn.close()
+        if (self.addr[0] != self.ip):
+            self.getdata()
+            self.conn.close()
+        else:
+            self.conn.close()
 
             
             
